@@ -23,7 +23,7 @@ from aliyunsdkmse.endpoint import endpoint_data
 class AddBlackWhiteListRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'mse', '2019-05-31', 'AddBlackWhiteList')
+		RpcRequest.__init__(self, 'mse', '2019-05-31', 'AddBlackWhiteList','mse')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -31,6 +31,11 @@ class AddBlackWhiteListRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_Note(self): # String
+		return self.get_query_params().get('Note')
+
+	def set_Note(self, Note):  # String
+		self.add_query_param('Note', Note)
 	def get_GatewayUniqueId(self): # String
 		return self.get_query_params().get('GatewayUniqueId')
 
@@ -51,11 +56,21 @@ class AddBlackWhiteListRequest(RpcRequest):
 
 	def set_IsWhite(self, IsWhite):  # Boolean
 		self.add_query_param('IsWhite', IsWhite)
+	def get_ResourceIdJsonList(self): # String
+		return self.get_query_params().get('ResourceIdJsonList')
+
+	def set_ResourceIdJsonList(self, ResourceIdJsonList):  # String
+		self.add_query_param('ResourceIdJsonList', ResourceIdJsonList)
 	def get_ResourceType(self): # String
 		return self.get_query_params().get('ResourceType')
 
 	def set_ResourceType(self, ResourceType):  # String
 		self.add_query_param('ResourceType', ResourceType)
+	def get_Name(self): # String
+		return self.get_query_params().get('Name')
+
+	def set_Name(self, Name):  # String
+		self.add_query_param('Name', Name)
 	def get_AcceptLanguage(self): # String
 		return self.get_query_params().get('AcceptLanguage')
 
