@@ -52,6 +52,11 @@ class AddServiceSourceRequest(RpcRequest):
 
 	def set_Type(self, Type):  # String
 		self.add_query_param('Type', Type)
+	def get_PathList(self): # Array
+		return self.get_query_params().get('PathList')
+
+	def set_PathList(self, PathList):  # Array
+		self.add_query_param("PathList", json.dumps(PathList))
 	def get_Address(self): # String
 		return self.get_query_params().get('Address')
 
@@ -67,3 +72,8 @@ class AddServiceSourceRequest(RpcRequest):
 
 	def set_AcceptLanguage(self, AcceptLanguage):  # String
 		self.add_query_param('AcceptLanguage', AcceptLanguage)
+	def get_GroupList(self): # Array
+		return self.get_query_params().get('GroupList')
+
+	def set_GroupList(self, GroupList):  # Array
+		self.add_query_param("GroupList", json.dumps(GroupList))
