@@ -23,7 +23,7 @@ from aliyunsdkmse.endpoint import endpoint_data
 class ListNacosHistoryConfigsRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'mse', '2019-05-31', 'ListNacosHistoryConfigs')
+		RpcRequest.__init__(self, 'mse', '2019-05-31', 'ListNacosHistoryConfigs','mse')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -36,16 +36,6 @@ class ListNacosHistoryConfigsRequest(RpcRequest):
 
 	def set_PageNum(self, PageNum):  # Integer
 		self.add_query_param('PageNum', PageNum)
-	def get_InstanceId(self): # String
-		return self.get_query_params().get('InstanceId')
-
-	def set_InstanceId(self, InstanceId):  # String
-		self.add_query_param('InstanceId', InstanceId)
-	def get_DataId(self): # String
-		return self.get_query_params().get('DataId')
-
-	def set_DataId(self, DataId):  # String
-		self.add_query_param('DataId', DataId)
 	def get_NamespaceId(self): # String
 		return self.get_query_params().get('NamespaceId')
 
@@ -61,13 +51,23 @@ class ListNacosHistoryConfigsRequest(RpcRequest):
 
 	def set_PageSize(self, PageSize):  # Integer
 		self.add_query_param('PageSize', PageSize)
-	def get_AcceptLanguage(self): # String
-		return self.get_query_params().get('AcceptLanguage')
-
-	def set_AcceptLanguage(self, AcceptLanguage):  # String
-		self.add_query_param('AcceptLanguage', AcceptLanguage)
 	def get_Group(self): # String
 		return self.get_query_params().get('Group')
 
 	def set_Group(self, Group):  # String
 		self.add_query_param('Group', Group)
+	def get_InstanceId(self): # String
+		return self.get_query_params().get('InstanceId')
+
+	def set_InstanceId(self, InstanceId):  # String
+		self.add_query_param('InstanceId', InstanceId)
+	def get_DataId(self): # String
+		return self.get_query_params().get('DataId')
+
+	def set_DataId(self, DataId):  # String
+		self.add_query_param('DataId', DataId)
+	def get_AcceptLanguage(self): # String
+		return self.get_query_params().get('AcceptLanguage')
+
+	def set_AcceptLanguage(self, AcceptLanguage):  # String
+		self.add_query_param('AcceptLanguage', AcceptLanguage)
