@@ -23,7 +23,7 @@ from aliyunsdkmse.endpoint import endpoint_data
 class QueryClusterDetailRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'mse', '2019-05-31', 'QueryClusterDetail')
+		RpcRequest.__init__(self, 'mse', '2019-05-31', 'QueryClusterDetail','mse')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -31,6 +31,11 @@ class QueryClusterDetailRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_AclSwitch(self): # Boolean
+		return self.get_query_params().get('AclSwitch')
+
+	def set_AclSwitch(self, AclSwitch):  # Boolean
+		self.add_query_param('AclSwitch', AclSwitch)
 	def get_OrderId(self): # String
 		return self.get_query_params().get('OrderId')
 
