@@ -36,6 +36,11 @@ class UpdateGatewayDomainRequest(RpcRequest):
 
 	def set_GatewayUniqueId(self, GatewayUniqueId):  # String
 		self.add_query_param('GatewayUniqueId', GatewayUniqueId)
+	def get_TlsMax(self): # String
+		return self.get_query_params().get('TlsMax')
+
+	def set_TlsMax(self, TlsMax):  # String
+		self.add_query_param('TlsMax', TlsMax)
 	def get_Protocol(self): # String
 		return self.get_query_params().get('Protocol')
 
@@ -46,11 +51,21 @@ class UpdateGatewayDomainRequest(RpcRequest):
 
 	def set_MustHttps(self, MustHttps):  # Boolean
 		self.add_query_param('MustHttps', MustHttps)
+	def get_Http2(self): # String
+		return self.get_query_params().get('Http2')
+
+	def set_Http2(self, Http2):  # String
+		self.add_query_param('Http2', Http2)
 	def get_Id(self): # Long
 		return self.get_query_params().get('Id')
 
 	def set_Id(self, Id):  # Long
 		self.add_query_param('Id', Id)
+	def get_TlsMin(self): # String
+		return self.get_query_params().get('TlsMin')
+
+	def set_TlsMin(self, TlsMin):  # String
+		self.add_query_param('TlsMin', TlsMin)
 	def get_CertIdentifier(self): # String
 		return self.get_query_params().get('CertIdentifier')
 
